<?php

declare(strict_types=1);

use apexl\Io\modules\file\interfaces\FileServiceInterface;
use apexl\Io\modules\file\services\IoFileService;
use function DI\autowire;

return [
    FileServiceInterface::class => autowire(IoFileService::class),
];